| Title: | Bivariate Pareto Models |
|---|---|
| Description: | Perform competing risks analysis under bivariate Pareto models. See Shih et al. (2019) <doi:10.1080/03610926.2018.1425450> for details. |
| Authors: | Jia-Han Shih, Wei Lee |
| Maintainer: | Jia-Han Shih <[email protected]> |
| License: | GPL-2 |
| Version: | 1.0.3 |
| Built: | 2026-05-18 07:47:11 UTC |
| Source: | https://github.com/cran/Bivariate.Pareto |
Perform competing risks analysis under bivariate Pareto models. See Shih et al. (2018) for details.
The functions in this package are based on latent failure time models with competing risks in Shih et al. (2018). However, they can be adapted to dependent censoring models in Emura and Chen (2018). See MLE.SN.Pareto for example.
Jia-Han Shih, Wei Lee
Maintainer: Jia-Han Shih <[email protected]>
Shih J-H, Lee W, Sun L-H, Emura T (2018), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, doi: 10.1080/03610926.2018.1425450.
Emura T, Chen Y-H (2018) Analysis of Survival Data with Dependent Censoring, Copula-Based Approaches, JSS Research Series in Statistics, Springer, in press.
Generate samples from the Frank copula with the Pareto margins.
Frank.Pareto(n, Theta, Alpha1, Alpha2, Gamma1, Gamma2)Frank.Pareto(n, Theta, Alpha1, Alpha2, Gamma1, Gamma2)
n |
Sample size. |
Theta |
Copula parameter |
Alpha1 |
Positive scale parameter |
Alpha2 |
Positive scale parameter |
Gamma1 |
Positive shape parameter |
Gamma2 |
Positive shape parameter |
X |
|
Y |
|
Shih J-H, Lee W, Sun L-H, Emura T (2019), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, 48:1193-1220.
library(Bivariate.Pareto) Frank.Pareto(5,5,1,1,1,1)library(Bivariate.Pareto) Frank.Pareto(5,5,1,1,1,1)
Compute Kendall's tau under the Sankaran and Nair bivairate Pareto (SNBP) distribution (Sankaran and Nair, 1993) by numerical integration.
Kendall.SNBP(Alpha0, Alpha1, Alpha2, Gamma)Kendall.SNBP(Alpha0, Alpha1, Alpha2, Gamma)
Alpha0 |
Copula parameter |
Alpha1 |
Positive scale parameter |
Alpha2 |
Positive scale parameter |
Gamma |
Common positive shape parameter |
The admissible range of Alpha0 () is
tau |
Kendall's tau. |
Sankaran PG, Nair NU (1993), A bivariate Pareto model and its applications to reliability, Naval Research Logistics, 40:1013-1020.
Shih J-H, Lee W, Sun L-H, Emura T (2019), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, 48:1193-1220.
library(Bivariate.Pareto) Kendall.SNBP(7e-5,0.0036,0.0075,1.8277)library(Bivariate.Pareto) Kendall.SNBP(7e-5,0.0036,0.0075,1.8277)
Maximum likelihood estimation for bivariate dependent competing risks data under the Frank copula with the Pareto margins and fixed .
MLE.Frank.Pareto( t.event, event1, event2, Theta, Alpha1.0 = 1, Alpha2.0 = 1, Gamma1.0 = 1, Gamma2.0 = 1, epsilon = 1e-05, d = exp(10), r.1 = 6, r.2 = 6, r.3 = 6, r.4 = 6 )MLE.Frank.Pareto( t.event, event1, event2, Theta, Alpha1.0 = 1, Alpha2.0 = 1, Gamma1.0 = 1, Gamma2.0 = 1, epsilon = 1e-05, d = exp(10), r.1 = 6, r.2 = 6, r.3 = 6, r.4 = 6 )
t.event |
Vector of the observed failure times. |
event1 |
Vector of the indicators for the failure cause 1. |
event2 |
Vector of the indicators for the failure cause 2. |
Theta |
Copula parameter |
Alpha1.0 |
Initial guess for the scale parameter |
Alpha2.0 |
Initial guess for the scale parameter |
Gamma1.0 |
Initial guess for the shape parameter |
Gamma2.0 |
Initial guess for the shape parameter |
epsilon |
Positive tunning parameter in the NR algorithm with default value |
d |
Positive tunning parameter in the NR algorithm with default value |
r.1 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.2 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.3 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.4 |
Positive tunning parameter in the NR algorithm with default value 1. |
n |
Sample size. |
count |
Iteration number. |
random |
Randomization number. |
Alpha1 |
Positive scale parameter for the Pareto margin (failure cause 1). |
Alpha2 |
Positive scale parameter for the Pareto margin (failure cause 2). |
Gamma1 |
Positive shape parameter for the Pareto margin (failure cause 1). |
Gamma2 |
Positive shape parameter for the Pareto margin (failure cause 2). |
MedX |
Median lifetime due to failure cause 1. |
MedY |
Median lifetime due to failure cause 2. |
MeanX |
Mean lifetime due to failure cause 1. |
MeanY |
Mean lifetime due to failure cause 2. |
logL |
Log-likelihood value under the fitted model. |
AIC |
AIC value under the fitted model. |
BIC |
BIC value under the fitted model. |
Shih J-H, Lee W, Sun L-H, Emura T (2018), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, doi: 10.1080/03610926.2018.1425450.
t.event = c(72,40,20,65,24,46,62,61,60,60,59,59,49,20, 3,58,29,26,52,20, 51,51,31,42,38,69,39,33, 8,13,33, 9,21,66, 5,27, 2,20,19,60, 32,53,53,43,21,74,72,14,33, 8,10,51, 7,33, 3,43,37, 5, 6, 2, 5,64, 1,21,16,21,12,75,74,54,73,36,59, 6,58,16,19,39,26,60, 43, 7, 9,67,62,17,25, 0, 5,34,59,31,58,30,57, 5,55,55,52, 0, 51,17,70,74,74,20, 2, 8,27,23, 1,52,51, 6, 0,26,65,26, 6, 6, 68,33,67,23, 6,11, 6,57,57,29, 9,53,51, 8, 0,21,27,22,12,68, 21,68, 0, 2,14,18, 5,60,40,51,50,46,65, 9,21,27,54,52,75,30, 70,14, 0,42,12,40, 2,12,53,11,18,13,45, 8,28,67,67,24,64,26, 57,32,42,20,71,54,64,51, 1, 2, 0,54,69,68,67,66,64,63,35,62, 7,35,24,57, 1, 4,74, 0,51,36,16,32,68,17,66,65,19,41,28, 0, 46,63,60,59,46,63, 8,74,18,33,12, 1,66,28,30,57,50,39,40,24, 6,30,58,68,24,33,65, 2,64,19,15,10,12,53,51, 1,40,40,66, 2, 21,35,29,54,37,10,29,71,12,13,27,66,28,31,12, 9,21,19,51,71, 76,46,47,75,75,49,75,75,31,69,74,25,72,28,36, 8,71,60,14,22, 67,62,68,68,27,68,68,67,67, 3,49,12,30,67, 5,65,24,66,36,66, 40,13,40, 0,14,45,64,13,24,15,26, 5,63,35,61,61,50,57,21,26, 11,59,42,27,50,57,57, 0, 1,54,53,23, 8,51,27,52,52,52,45,48, 18, 2, 2,35,75,75, 9,39, 0,26,17,43,53,47,11,65,16,21,64, 7, 38,55, 5,28,38,20,24,27,31, 9, 9,11,56,36,56,15,51,33,70,32, 5,23,63,30,53,12,58,54,36,20,74,34,70,25,65, 4,10,58,37,56, 6, 0,70,70,28,40,67,36,23,23,62,62,62, 2,34, 4,12,56, 1, 7, 4,70,65, 7,30,40,13,22, 0,18,64,13,26, 1,16,33,22,30,53,53, 7,61,40, 9,59, 7,12,46,50, 0,52,19,52,51,51,14,27,51, 5, 0, 41,53,19) event1 = c(0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0, 0,0,1,0,0,0,1,0,1,1,0,1,1,1,1,0,0,1,1,0, 1,0,0,1,1,0,0,1,0,0,0,1,0,1,0,0,1,0,1,1, 1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,0,0,0,0,1,1,0,0,1,0,0, 0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0, 0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,1,0,0,0,0,1,0,0,0,0,0, 1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,1,0,0,1,1,0,1,0,0,1,1,0,0, 1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0, 0,0,1,0,1,0,0,0,0,1,1,1,1,0,0,0,1,1,0,0, 1,1,1,1,0,0,1,0,1,1,1,1,1,1,1,0,1,1,0,1, 0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1, 0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 1,0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,0,0,1, 1,1,0,1,1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,0, 0,0,0,1,0,0,0,0,1,0,0,1,0,1,0,1,1,0,1,0, 1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0, 1,0,0,1,0,0,0,1,0,1,0,0,1,0,0,0,1,1,0,1, 1,1,1,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,0, 0,0,1) event2 = c(0,1,1,0,0,1,0,0,0,0,0,0,0,1,1,0,1,1,0,1, 0,0,0,1,1,0,0,1,0,0,1,0,0,0,0,1,1,0,0,0, 0,0,0,0,0,0,0,0,1,1,1,0,1,0,1,1,0,1,0,0, 0,0,1,0,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1, 1,1,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,0,0,1, 0,1,1,0,0,1,0,0,1,1,1,0,0,0,0,1,1,0,1,1, 0,1,0,0,1,1,0,0,0,1,1,0,0,1,1,1,0,1,0,0, 1,0,1,0,0,1,0,0,1,0,1,1,0,1,1,1,0,0,0,1, 0,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,1, 0,0,1,1,0,1,0,1,1,1,0,1,0,0,0,0,0,0,1,0, 1,1,1,0,1,1,1,0,1,1,0,0,0,0,0,0,0,0,1,1, 0,0,0,0,1,0,1,0,1,1,1,1,0,1,1,1,0,1,1,1, 1,1,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,0,0,1, 0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0, 0,0,1,0,0,1,0,0,1,0,0,1,0,1,1,0,0,1,1,1, 1,1,0,0,1,0,0,0,0,1,1,1,1,0,1,1,1,0,1,0, 1,1,1,1,1,1,0,1,1,1,1,0,0,1,0,0,1,1,1,0, 1,0,0,1,1,0,0,1,1,0,0,1,1,1,1,0,0,0,1,1, 0,1,1,1,0,0,1,0,1,1,1,1,0,1,0,0,0,1,0,0, 0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1, 1,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,1,0,0,1,1,0,1,1,1,0,0,0,1,0,1,0,0,1,1, 0,0,0,0,1,1,1,0,1,0,1,1,0,1,1,1,0,0,1,0, 0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,1,1, 1,0,0) library(Bivariate.Pareto) set.seed(10) MLE.Frank.Pareto(t.event,event1,event2,Theta = -5)t.event = c(72,40,20,65,24,46,62,61,60,60,59,59,49,20, 3,58,29,26,52,20, 51,51,31,42,38,69,39,33, 8,13,33, 9,21,66, 5,27, 2,20,19,60, 32,53,53,43,21,74,72,14,33, 8,10,51, 7,33, 3,43,37, 5, 6, 2, 5,64, 1,21,16,21,12,75,74,54,73,36,59, 6,58,16,19,39,26,60, 43, 7, 9,67,62,17,25, 0, 5,34,59,31,58,30,57, 5,55,55,52, 0, 51,17,70,74,74,20, 2, 8,27,23, 1,52,51, 6, 0,26,65,26, 6, 6, 68,33,67,23, 6,11, 6,57,57,29, 9,53,51, 8, 0,21,27,22,12,68, 21,68, 0, 2,14,18, 5,60,40,51,50,46,65, 9,21,27,54,52,75,30, 70,14, 0,42,12,40, 2,12,53,11,18,13,45, 8,28,67,67,24,64,26, 57,32,42,20,71,54,64,51, 1, 2, 0,54,69,68,67,66,64,63,35,62, 7,35,24,57, 1, 4,74, 0,51,36,16,32,68,17,66,65,19,41,28, 0, 46,63,60,59,46,63, 8,74,18,33,12, 1,66,28,30,57,50,39,40,24, 6,30,58,68,24,33,65, 2,64,19,15,10,12,53,51, 1,40,40,66, 2, 21,35,29,54,37,10,29,71,12,13,27,66,28,31,12, 9,21,19,51,71, 76,46,47,75,75,49,75,75,31,69,74,25,72,28,36, 8,71,60,14,22, 67,62,68,68,27,68,68,67,67, 3,49,12,30,67, 5,65,24,66,36,66, 40,13,40, 0,14,45,64,13,24,15,26, 5,63,35,61,61,50,57,21,26, 11,59,42,27,50,57,57, 0, 1,54,53,23, 8,51,27,52,52,52,45,48, 18, 2, 2,35,75,75, 9,39, 0,26,17,43,53,47,11,65,16,21,64, 7, 38,55, 5,28,38,20,24,27,31, 9, 9,11,56,36,56,15,51,33,70,32, 5,23,63,30,53,12,58,54,36,20,74,34,70,25,65, 4,10,58,37,56, 6, 0,70,70,28,40,67,36,23,23,62,62,62, 2,34, 4,12,56, 1, 7, 4,70,65, 7,30,40,13,22, 0,18,64,13,26, 1,16,33,22,30,53,53, 7,61,40, 9,59, 7,12,46,50, 0,52,19,52,51,51,14,27,51, 5, 0, 41,53,19) event1 = c(0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0, 0,0,1,0,0,0,1,0,1,1,0,1,1,1,1,0,0,1,1,0, 1,0,0,1,1,0,0,1,0,0,0,1,0,1,0,0,1,0,1,1, 1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,0,0,0,0,1,1,0,0,1,0,0, 0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0, 0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,1,0,0,0,0,1,0,0,0,0,0, 1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,1,0,0,1,1,0,1,0,0,1,1,0,0, 1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0, 0,0,1,0,1,0,0,0,0,1,1,1,1,0,0,0,1,1,0,0, 1,1,1,1,0,0,1,0,1,1,1,1,1,1,1,0,1,1,0,1, 0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1, 0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 1,0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,0,0,1, 1,1,0,1,1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,0, 0,0,0,1,0,0,0,0,1,0,0,1,0,1,0,1,1,0,1,0, 1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0, 1,0,0,1,0,0,0,1,0,1,0,0,1,0,0,0,1,1,0,1, 1,1,1,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,0, 0,0,1) event2 = c(0,1,1,0,0,1,0,0,0,0,0,0,0,1,1,0,1,1,0,1, 0,0,0,1,1,0,0,1,0,0,1,0,0,0,0,1,1,0,0,0, 0,0,0,0,0,0,0,0,1,1,1,0,1,0,1,1,0,1,0,0, 0,0,1,0,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1, 1,1,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,0,0,1, 0,1,1,0,0,1,0,0,1,1,1,0,0,0,0,1,1,0,1,1, 0,1,0,0,1,1,0,0,0,1,1,0,0,1,1,1,0,1,0,0, 1,0,1,0,0,1,0,0,1,0,1,1,0,1,1,1,0,0,0,1, 0,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,1, 0,0,1,1,0,1,0,1,1,1,0,1,0,0,0,0,0,0,1,0, 1,1,1,0,1,1,1,0,1,1,0,0,0,0,0,0,0,0,1,1, 0,0,0,0,1,0,1,0,1,1,1,1,0,1,1,1,0,1,1,1, 1,1,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,0,0,1, 0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0, 0,0,1,0,0,1,0,0,1,0,0,1,0,1,1,0,0,1,1,1, 1,1,0,0,1,0,0,0,0,1,1,1,1,0,1,1,1,0,1,0, 1,1,1,1,1,1,0,1,1,1,1,0,0,1,0,0,1,1,1,0, 1,0,0,1,1,0,0,1,1,0,0,1,1,1,1,0,0,0,1,1, 0,1,1,1,0,0,1,0,1,1,1,1,0,1,0,0,0,1,0,0, 0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1, 1,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,1,0,0,1,1,0,1,1,1,0,0,0,1,0,1,0,0,1,1, 0,0,0,0,1,1,1,0,1,0,1,1,0,1,1,1,0,0,1,0, 0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,1,1, 1,0,0) library(Bivariate.Pareto) set.seed(10) MLE.Frank.Pareto(t.event,event1,event2,Theta = -5)
Maximum likelihood estimation for bivariate dependent competing risks data under the Frank copula with the common Pareto margins.
MLE.Frank.Pareto.com( t.event, event1, event2, Theta.0 = 1, Alpha.0 = 1, Gamma.0 = 1, epsilon = 1e-05, r.1 = 13, r.2 = 3, r.3 = 3, bootstrap = FALSE, B = 200 )MLE.Frank.Pareto.com( t.event, event1, event2, Theta.0 = 1, Alpha.0 = 1, Gamma.0 = 1, epsilon = 1e-05, r.1 = 13, r.2 = 3, r.3 = 3, bootstrap = FALSE, B = 200 )
t.event |
Vector of the observed failure times. |
event1 |
Vector of the indicators for the failure cause 1. |
event2 |
Vector of the indicators for the failure cause 2. |
Theta.0 |
Initial guess for the copula parameter |
Alpha.0 |
Initial guess for the common scale parameter |
Gamma.0 |
Initial guess for the common shape parameter |
epsilon |
Positive tunning parameter in the NR algorithm with default value |
r.1 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.2 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.3 |
Positive tunning parameter in the NR algorithm with default value 1. |
bootstrap |
Perform parametric bootstrap if |
B |
Number of bootstrap replications. |
The parametric bootstrap method requires the assumption of the uniform censoring distribution. One must notice that such assumption is not always true in real data analysis.
n |
Sample size. |
count |
Iteration number. |
random |
Randomization number. |
Theta |
Copula parameter. |
Theta.B |
Copula parameter (SE and CI are calculated by parametric bootstrap method). |
Alpha |
Common positive scale parameter for the Pareto margin. |
Alpha.B |
Common positive scale parameter for the Pareto margin (SE and CI are calculated by parametric bootstrap method). |
Gamma |
Common positive shape parameter for the Pareto margin. |
Gamma.B |
Common positive shape parameter for the Pareto margin (SE and CI are calculated by parametric bootstrap method). |
logL |
Log-likelihood value under the fitted model. |
AIC |
AIC value under the fitted model. |
BIC |
BIC value under the fitted model. |
Shih J-H, Lee W, Sun L-H, Emura T (2019), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, 48:1193-1220.
t.event = c(72,40,20,65,24,46,62,61,60,60,59,59,49,20, 3,58,29,26,52,20, 51,51,31,42,38,69,39,33, 8,13,33, 9,21,66, 5,27, 2,20,19,60, 32,53,53,43,21,74,72,14,33, 8,10,51, 7,33, 3,43,37, 5, 6, 2, 5,64, 1,21,16,21,12,75,74,54,73,36,59, 6,58,16,19,39,26,60, 43, 7, 9,67,62,17,25, 0, 5,34,59,31,58,30,57, 5,55,55,52, 0, 51,17,70,74,74,20, 2, 8,27,23, 1,52,51, 6, 0,26,65,26, 6, 6, 68,33,67,23, 6,11, 6,57,57,29, 9,53,51, 8, 0,21,27,22,12,68, 21,68, 0, 2,14,18, 5,60,40,51,50,46,65, 9,21,27,54,52,75,30, 70,14, 0,42,12,40, 2,12,53,11,18,13,45, 8,28,67,67,24,64,26, 57,32,42,20,71,54,64,51, 1, 2, 0,54,69,68,67,66,64,63,35,62, 7,35,24,57, 1, 4,74, 0,51,36,16,32,68,17,66,65,19,41,28, 0, 46,63,60,59,46,63, 8,74,18,33,12, 1,66,28,30,57,50,39,40,24, 6,30,58,68,24,33,65, 2,64,19,15,10,12,53,51, 1,40,40,66, 2, 21,35,29,54,37,10,29,71,12,13,27,66,28,31,12, 9,21,19,51,71, 76,46,47,75,75,49,75,75,31,69,74,25,72,28,36, 8,71,60,14,22, 67,62,68,68,27,68,68,67,67, 3,49,12,30,67, 5,65,24,66,36,66, 40,13,40, 0,14,45,64,13,24,15,26, 5,63,35,61,61,50,57,21,26, 11,59,42,27,50,57,57, 0, 1,54,53,23, 8,51,27,52,52,52,45,48, 18, 2, 2,35,75,75, 9,39, 0,26,17,43,53,47,11,65,16,21,64, 7, 38,55, 5,28,38,20,24,27,31, 9, 9,11,56,36,56,15,51,33,70,32, 5,23,63,30,53,12,58,54,36,20,74,34,70,25,65, 4,10,58,37,56, 6, 0,70,70,28,40,67,36,23,23,62,62,62, 2,34, 4,12,56, 1, 7, 4,70,65, 7,30,40,13,22, 0,18,64,13,26, 1,16,33,22,30,53,53, 7,61,40, 9,59, 7,12,46,50, 0,52,19,52,51,51,14,27,51, 5, 0, 41,53,19) event1 = c(0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0, 0,0,1,0,0,0,1,0,1,1,0,1,1,1,1,0,0,1,1,0, 1,0,0,1,1,0,0,1,0,0,0,1,0,1,0,0,1,0,1,1, 1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,0,0,0,0,1,1,0,0,1,0,0, 0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0, 0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,1,0,0,0,0,1,0,0,0,0,0, 1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,1,0,0,1,1,0,1,0,0,1,1,0,0, 1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0, 0,0,1,0,1,0,0,0,0,1,1,1,1,0,0,0,1,1,0,0, 1,1,1,1,0,0,1,0,1,1,1,1,1,1,1,0,1,1,0,1, 0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1, 0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 1,0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,0,0,1, 1,1,0,1,1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,0, 0,0,0,1,0,0,0,0,1,0,0,1,0,1,0,1,1,0,1,0, 1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0, 1,0,0,1,0,0,0,1,0,1,0,0,1,0,0,0,1,1,0,1, 1,1,1,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,0, 0,0,1) event2 = c(0,1,1,0,0,1,0,0,0,0,0,0,0,1,1,0,1,1,0,1, 0,0,0,1,1,0,0,1,0,0,1,0,0,0,0,1,1,0,0,0, 0,0,0,0,0,0,0,0,1,1,1,0,1,0,1,1,0,1,0,0, 0,0,1,0,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1, 1,1,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,0,0,1, 0,1,1,0,0,1,0,0,1,1,1,0,0,0,0,1,1,0,1,1, 0,1,0,0,1,1,0,0,0,1,1,0,0,1,1,1,0,1,0,0, 1,0,1,0,0,1,0,0,1,0,1,1,0,1,1,1,0,0,0,1, 0,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,1, 0,0,1,1,0,1,0,1,1,1,0,1,0,0,0,0,0,0,1,0, 1,1,1,0,1,1,1,0,1,1,0,0,0,0,0,0,0,0,1,1, 0,0,0,0,1,0,1,0,1,1,1,1,0,1,1,1,0,1,1,1, 1,1,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,0,0,1, 0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0, 0,0,1,0,0,1,0,0,1,0,0,1,0,1,1,0,0,1,1,1, 1,1,0,0,1,0,0,0,0,1,1,1,1,0,1,1,1,0,1,0, 1,1,1,1,1,1,0,1,1,1,1,0,0,1,0,0,1,1,1,0, 1,0,0,1,1,0,0,1,1,0,0,1,1,1,1,0,0,0,1,1, 0,1,1,1,0,0,1,0,1,1,1,1,0,1,0,0,0,1,0,0, 0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1, 1,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,1,0,0,1,1,0,1,1,1,0,0,0,1,0,1,0,0,1,1, 0,0,0,0,1,1,1,0,1,0,1,1,0,1,1,1,0,0,1,0, 0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,1,1, 1,0,0) library(Bivariate.Pareto) set.seed(10) MLE.Frank.Pareto.com(t.event,event1,event2,bootstrap = FALSE)t.event = c(72,40,20,65,24,46,62,61,60,60,59,59,49,20, 3,58,29,26,52,20, 51,51,31,42,38,69,39,33, 8,13,33, 9,21,66, 5,27, 2,20,19,60, 32,53,53,43,21,74,72,14,33, 8,10,51, 7,33, 3,43,37, 5, 6, 2, 5,64, 1,21,16,21,12,75,74,54,73,36,59, 6,58,16,19,39,26,60, 43, 7, 9,67,62,17,25, 0, 5,34,59,31,58,30,57, 5,55,55,52, 0, 51,17,70,74,74,20, 2, 8,27,23, 1,52,51, 6, 0,26,65,26, 6, 6, 68,33,67,23, 6,11, 6,57,57,29, 9,53,51, 8, 0,21,27,22,12,68, 21,68, 0, 2,14,18, 5,60,40,51,50,46,65, 9,21,27,54,52,75,30, 70,14, 0,42,12,40, 2,12,53,11,18,13,45, 8,28,67,67,24,64,26, 57,32,42,20,71,54,64,51, 1, 2, 0,54,69,68,67,66,64,63,35,62, 7,35,24,57, 1, 4,74, 0,51,36,16,32,68,17,66,65,19,41,28, 0, 46,63,60,59,46,63, 8,74,18,33,12, 1,66,28,30,57,50,39,40,24, 6,30,58,68,24,33,65, 2,64,19,15,10,12,53,51, 1,40,40,66, 2, 21,35,29,54,37,10,29,71,12,13,27,66,28,31,12, 9,21,19,51,71, 76,46,47,75,75,49,75,75,31,69,74,25,72,28,36, 8,71,60,14,22, 67,62,68,68,27,68,68,67,67, 3,49,12,30,67, 5,65,24,66,36,66, 40,13,40, 0,14,45,64,13,24,15,26, 5,63,35,61,61,50,57,21,26, 11,59,42,27,50,57,57, 0, 1,54,53,23, 8,51,27,52,52,52,45,48, 18, 2, 2,35,75,75, 9,39, 0,26,17,43,53,47,11,65,16,21,64, 7, 38,55, 5,28,38,20,24,27,31, 9, 9,11,56,36,56,15,51,33,70,32, 5,23,63,30,53,12,58,54,36,20,74,34,70,25,65, 4,10,58,37,56, 6, 0,70,70,28,40,67,36,23,23,62,62,62, 2,34, 4,12,56, 1, 7, 4,70,65, 7,30,40,13,22, 0,18,64,13,26, 1,16,33,22,30,53,53, 7,61,40, 9,59, 7,12,46,50, 0,52,19,52,51,51,14,27,51, 5, 0, 41,53,19) event1 = c(0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0, 0,0,1,0,0,0,1,0,1,1,0,1,1,1,1,0,0,1,1,0, 1,0,0,1,1,0,0,1,0,0,0,1,0,1,0,0,1,0,1,1, 1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,0,0,0,0,1,1,0,0,1,0,0, 0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0, 0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,1,0,0,0,0,1,0,0,0,0,0, 1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,1,0,0,1,1,0,1,0,0,1,1,0,0, 1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0, 0,0,1,0,1,0,0,0,0,1,1,1,1,0,0,0,1,1,0,0, 1,1,1,1,0,0,1,0,1,1,1,1,1,1,1,0,1,1,0,1, 0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1, 0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 1,0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,0,0,1, 1,1,0,1,1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,0, 0,0,0,1,0,0,0,0,1,0,0,1,0,1,0,1,1,0,1,0, 1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0, 1,0,0,1,0,0,0,1,0,1,0,0,1,0,0,0,1,1,0,1, 1,1,1,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,0, 0,0,1) event2 = c(0,1,1,0,0,1,0,0,0,0,0,0,0,1,1,0,1,1,0,1, 0,0,0,1,1,0,0,1,0,0,1,0,0,0,0,1,1,0,0,0, 0,0,0,0,0,0,0,0,1,1,1,0,1,0,1,1,0,1,0,0, 0,0,1,0,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1, 1,1,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,0,0,1, 0,1,1,0,0,1,0,0,1,1,1,0,0,0,0,1,1,0,1,1, 0,1,0,0,1,1,0,0,0,1,1,0,0,1,1,1,0,1,0,0, 1,0,1,0,0,1,0,0,1,0,1,1,0,1,1,1,0,0,0,1, 0,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,1, 0,0,1,1,0,1,0,1,1,1,0,1,0,0,0,0,0,0,1,0, 1,1,1,0,1,1,1,0,1,1,0,0,0,0,0,0,0,0,1,1, 0,0,0,0,1,0,1,0,1,1,1,1,0,1,1,1,0,1,1,1, 1,1,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,0,0,1, 0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0, 0,0,1,0,0,1,0,0,1,0,0,1,0,1,1,0,0,1,1,1, 1,1,0,0,1,0,0,0,0,1,1,1,1,0,1,1,1,0,1,0, 1,1,1,1,1,1,0,1,1,1,1,0,0,1,0,0,1,1,1,0, 1,0,0,1,1,0,0,1,1,0,0,1,1,1,1,0,0,0,1,1, 0,1,1,1,0,0,1,0,1,1,1,1,0,1,0,0,0,1,0,0, 0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1, 1,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,1,0,0,1,1,0,1,1,1,0,0,0,1,0,1,0,0,1,1, 0,0,0,0,1,1,1,0,1,0,1,1,0,1,1,1,0,0,1,0, 0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,1,1, 1,0,0) library(Bivariate.Pareto) set.seed(10) MLE.Frank.Pareto.com(t.event,event1,event2,bootstrap = FALSE)
Maximum likelihood estimation for bivariate dependent competing risks data under the SNBP distribution (Sankaran and Nair, 1993).
MLE.SN.Pareto( t.event, event1, event2, Alpha0, Alpha1.0 = 1, Alpha2.0 = 1, Gamma.0 = 1, epsilon = 1e-05, d = exp(10), r.1 = 6, r.2 = 6, r.3 = 6 )MLE.SN.Pareto( t.event, event1, event2, Alpha0, Alpha1.0 = 1, Alpha2.0 = 1, Gamma.0 = 1, epsilon = 1e-05, d = exp(10), r.1 = 6, r.2 = 6, r.3 = 6 )
t.event |
Vector of the observed failure times. |
event1 |
Vector of the indicators for the failure cause 1. |
event2 |
Vector of the indicators for the failure cause 2. |
Alpha0 |
Copula parameter |
Alpha1.0 |
Initial guess for the scale parameter |
Alpha2.0 |
Initial guess for the scale parameter |
Gamma.0 |
Initial guess for the common shape parameter |
epsilon |
Positive tunning parameter in the NR algorithm with default value |
d |
Positive tunning parameter in the NR algorithm with default value |
r.1 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.2 |
Positive tunning parameter in the NR algorithm with default value 1. |
r.3 |
Positive tunning parameter in the NR algorithm with default value 1. |
The admissible range of Alpha0 () is
To adapt our functions to dependent censoring models in Emura and Chen (2018), one can simply set event2 = 1-event1.
n |
Sample size. |
count |
Iteration number. |
random |
Randomization number. |
Alpha1 |
Positive scale parameter for the Pareto margin (failure cause 1). |
Alpha2 |
Positive scale parameter for the Pareto margin (failure cause 2). |
Gamma |
Common positive shape parameter for the Pareto margins. |
MedX |
Median lifetime due to failure cause 1. |
MedY |
Median lifetime due to failure cause 2. |
MeanX |
Mean lifetime due to failure cause 1. |
MeanY |
Mean lifetime due to failure cause 2. |
logL |
Log-likelihood value under the fitted model. |
AIC |
AIC value under the fitted model. |
BIC |
BIC value under the fitted model. |
Sankaran PG, Nair NU (1993), A bivariate Pareto model and its applications to reliability, Naval Research Logistics, 40(7): 1013-1020.
Emura T, Chen Y-H (2018) Analysis of Survival Data with Dependent Censoring, Copula-Based Approaches, JSS Research Series in Statistics, Springer, Singapore.
Shih J-H, Lee W, Sun L-H, Emura T (2019), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, 48:1193-1220.
t.event = c(72,40,20,65,24,46,62,61,60,60,59,59,49,20, 3,58,29,26,52,20, 51,51,31,42,38,69,39,33, 8,13,33, 9,21,66, 5,27, 2,20,19,60, 32,53,53,43,21,74,72,14,33, 8,10,51, 7,33, 3,43,37, 5, 6, 2, 5,64, 1,21,16,21,12,75,74,54,73,36,59, 6,58,16,19,39,26,60, 43, 7, 9,67,62,17,25, 0, 5,34,59,31,58,30,57, 5,55,55,52, 0, 51,17,70,74,74,20, 2, 8,27,23, 1,52,51, 6, 0,26,65,26, 6, 6, 68,33,67,23, 6,11, 6,57,57,29, 9,53,51, 8, 0,21,27,22,12,68, 21,68, 0, 2,14,18, 5,60,40,51,50,46,65, 9,21,27,54,52,75,30, 70,14, 0,42,12,40, 2,12,53,11,18,13,45, 8,28,67,67,24,64,26, 57,32,42,20,71,54,64,51, 1, 2, 0,54,69,68,67,66,64,63,35,62, 7,35,24,57, 1, 4,74, 0,51,36,16,32,68,17,66,65,19,41,28, 0, 46,63,60,59,46,63, 8,74,18,33,12, 1,66,28,30,57,50,39,40,24, 6,30,58,68,24,33,65, 2,64,19,15,10,12,53,51, 1,40,40,66, 2, 21,35,29,54,37,10,29,71,12,13,27,66,28,31,12, 9,21,19,51,71, 76,46,47,75,75,49,75,75,31,69,74,25,72,28,36, 8,71,60,14,22, 67,62,68,68,27,68,68,67,67, 3,49,12,30,67, 5,65,24,66,36,66, 40,13,40, 0,14,45,64,13,24,15,26, 5,63,35,61,61,50,57,21,26, 11,59,42,27,50,57,57, 0, 1,54,53,23, 8,51,27,52,52,52,45,48, 18, 2, 2,35,75,75, 9,39, 0,26,17,43,53,47,11,65,16,21,64, 7, 38,55, 5,28,38,20,24,27,31, 9, 9,11,56,36,56,15,51,33,70,32, 5,23,63,30,53,12,58,54,36,20,74,34,70,25,65, 4,10,58,37,56, 6, 0,70,70,28,40,67,36,23,23,62,62,62, 2,34, 4,12,56, 1, 7, 4,70,65, 7,30,40,13,22, 0,18,64,13,26, 1,16,33,22,30,53,53, 7,61,40, 9,59, 7,12,46,50, 0,52,19,52,51,51,14,27,51, 5, 0, 41,53,19) event1 = c(0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0, 0,0,1,0,0,0,1,0,1,1,0,1,1,1,1,0,0,1,1,0, 1,0,0,1,1,0,0,1,0,0,0,1,0,1,0,0,1,0,1,1, 1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,0,0,0,0,1,1,0,0,1,0,0, 0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0, 0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,1,0,0,0,0,1,0,0,0,0,0, 1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,1,0,0,1,1,0,1,0,0,1,1,0,0, 1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0, 0,0,1,0,1,0,0,0,0,1,1,1,1,0,0,0,1,1,0,0, 1,1,1,1,0,0,1,0,1,1,1,1,1,1,1,0,1,1,0,1, 0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1, 0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 1,0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,0,0,1, 1,1,0,1,1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,0, 0,0,0,1,0,0,0,0,1,0,0,1,0,1,0,1,1,0,1,0, 1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0, 1,0,0,1,0,0,0,1,0,1,0,0,1,0,0,0,1,1,0,1, 1,1,1,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,0, 0,0,1) event2 = c(0,1,1,0,0,1,0,0,0,0,0,0,0,1,1,0,1,1,0,1, 0,0,0,1,1,0,0,1,0,0,1,0,0,0,0,1,1,0,0,0, 0,0,0,0,0,0,0,0,1,1,1,0,1,0,1,1,0,1,0,0, 0,0,1,0,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1, 1,1,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,0,0,1, 0,1,1,0,0,1,0,0,1,1,1,0,0,0,0,1,1,0,1,1, 0,1,0,0,1,1,0,0,0,1,1,0,0,1,1,1,0,1,0,0, 1,0,1,0,0,1,0,0,1,0,1,1,0,1,1,1,0,0,0,1, 0,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,1, 0,0,1,1,0,1,0,1,1,1,0,1,0,0,0,0,0,0,1,0, 1,1,1,0,1,1,1,0,1,1,0,0,0,0,0,0,0,0,1,1, 0,0,0,0,1,0,1,0,1,1,1,1,0,1,1,1,0,1,1,1, 1,1,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,0,0,1, 0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0, 0,0,1,0,0,1,0,0,1,0,0,1,0,1,1,0,0,1,1,1, 1,1,0,0,1,0,0,0,0,1,1,1,1,0,1,1,1,0,1,0, 1,1,1,1,1,1,0,1,1,1,1,0,0,1,0,0,1,1,1,0, 1,0,0,1,1,0,0,1,1,0,0,1,1,1,1,0,0,0,1,1, 0,1,1,1,0,0,1,0,1,1,1,1,0,1,0,0,0,1,0,0, 0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1, 1,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,1,0,0,1,1,0,1,1,1,0,0,0,1,0,1,0,0,1,1, 0,0,0,0,1,1,1,0,1,0,1,1,0,1,1,1,0,0,1,0, 0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,1,1, 1,0,0) library(Bivariate.Pareto) set.seed(10) MLE.SN.Pareto(t.event,event1,event2,Alpha0 = 7e-5)t.event = c(72,40,20,65,24,46,62,61,60,60,59,59,49,20, 3,58,29,26,52,20, 51,51,31,42,38,69,39,33, 8,13,33, 9,21,66, 5,27, 2,20,19,60, 32,53,53,43,21,74,72,14,33, 8,10,51, 7,33, 3,43,37, 5, 6, 2, 5,64, 1,21,16,21,12,75,74,54,73,36,59, 6,58,16,19,39,26,60, 43, 7, 9,67,62,17,25, 0, 5,34,59,31,58,30,57, 5,55,55,52, 0, 51,17,70,74,74,20, 2, 8,27,23, 1,52,51, 6, 0,26,65,26, 6, 6, 68,33,67,23, 6,11, 6,57,57,29, 9,53,51, 8, 0,21,27,22,12,68, 21,68, 0, 2,14,18, 5,60,40,51,50,46,65, 9,21,27,54,52,75,30, 70,14, 0,42,12,40, 2,12,53,11,18,13,45, 8,28,67,67,24,64,26, 57,32,42,20,71,54,64,51, 1, 2, 0,54,69,68,67,66,64,63,35,62, 7,35,24,57, 1, 4,74, 0,51,36,16,32,68,17,66,65,19,41,28, 0, 46,63,60,59,46,63, 8,74,18,33,12, 1,66,28,30,57,50,39,40,24, 6,30,58,68,24,33,65, 2,64,19,15,10,12,53,51, 1,40,40,66, 2, 21,35,29,54,37,10,29,71,12,13,27,66,28,31,12, 9,21,19,51,71, 76,46,47,75,75,49,75,75,31,69,74,25,72,28,36, 8,71,60,14,22, 67,62,68,68,27,68,68,67,67, 3,49,12,30,67, 5,65,24,66,36,66, 40,13,40, 0,14,45,64,13,24,15,26, 5,63,35,61,61,50,57,21,26, 11,59,42,27,50,57,57, 0, 1,54,53,23, 8,51,27,52,52,52,45,48, 18, 2, 2,35,75,75, 9,39, 0,26,17,43,53,47,11,65,16,21,64, 7, 38,55, 5,28,38,20,24,27,31, 9, 9,11,56,36,56,15,51,33,70,32, 5,23,63,30,53,12,58,54,36,20,74,34,70,25,65, 4,10,58,37,56, 6, 0,70,70,28,40,67,36,23,23,62,62,62, 2,34, 4,12,56, 1, 7, 4,70,65, 7,30,40,13,22, 0,18,64,13,26, 1,16,33,22,30,53,53, 7,61,40, 9,59, 7,12,46,50, 0,52,19,52,51,51,14,27,51, 5, 0, 41,53,19) event1 = c(0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0, 0,0,1,0,0,0,1,0,1,1,0,1,1,1,1,0,0,1,1,0, 1,0,0,1,1,0,0,1,0,0,0,1,0,1,0,0,1,0,1,1, 1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,0,0,0,0,1,1,0,0,1,0,0, 0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0, 0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,1,1,0,1,0,0,0,0,1,0,0,0,0,0, 1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,1,0,0,1,1,0,1,0,0,1,1,0,0, 1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0, 0,0,1,0,1,0,0,0,0,1,1,1,1,0,0,0,1,1,0,0, 1,1,1,1,0,0,1,0,1,1,1,1,1,1,1,0,1,1,0,1, 0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1, 0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0, 1,0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,0,0,1, 1,1,0,1,1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,0, 0,0,0,1,0,0,0,0,1,0,0,1,0,1,0,1,1,0,1,0, 1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0, 1,0,0,1,0,0,0,1,0,1,0,0,1,0,0,0,1,1,0,1, 1,1,1,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,0, 0,0,1) event2 = c(0,1,1,0,0,1,0,0,0,0,0,0,0,1,1,0,1,1,0,1, 0,0,0,1,1,0,0,1,0,0,1,0,0,0,0,1,1,0,0,0, 0,0,0,0,0,0,0,0,1,1,1,0,1,0,1,1,0,1,0,0, 0,0,1,0,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1, 1,1,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,0,0,1, 0,1,1,0,0,1,0,0,1,1,1,0,0,0,0,1,1,0,1,1, 0,1,0,0,1,1,0,0,0,1,1,0,0,1,1,1,0,1,0,0, 1,0,1,0,0,1,0,0,1,0,1,1,0,1,1,1,0,0,0,1, 0,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,1, 0,0,1,1,0,1,0,1,1,1,0,1,0,0,0,0,0,0,1,0, 1,1,1,0,1,1,1,0,1,1,0,0,0,0,0,0,0,0,1,1, 0,0,0,0,1,0,1,0,1,1,1,1,0,1,1,1,0,1,1,1, 1,1,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,0,0,1, 0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0, 0,0,1,0,0,1,0,0,1,0,0,1,0,1,1,0,0,1,1,1, 1,1,0,0,1,0,0,0,0,1,1,1,1,0,1,1,1,0,1,0, 1,1,1,1,1,1,0,1,1,1,1,0,0,1,0,0,1,1,1,0, 1,0,0,1,1,0,0,1,1,0,0,1,1,1,1,0,0,0,1,1, 0,1,1,1,0,0,1,0,1,1,1,1,0,1,0,0,0,1,0,0, 0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1, 1,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0, 0,1,0,0,1,1,0,1,1,1,0,0,0,1,0,1,0,0,1,1, 0,0,0,0,1,1,1,0,1,0,1,1,0,1,1,1,0,0,1,0, 0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,1,1, 1,0,0) library(Bivariate.Pareto) set.seed(10) MLE.SN.Pareto(t.event,event1,event2,Alpha0 = 7e-5)
Generate samples from the Sankaran and Nair bivairate Pareto (SNBP) distribution (Sankaran and Nair, 1993).
SN.Pareto(n, Alpha0, Alpha1, Alpha2, Gamma)SN.Pareto(n, Alpha0, Alpha1, Alpha2, Gamma)
n |
Sample size. |
Alpha0 |
Copula parameter |
Alpha1 |
Positive scale parameter |
Alpha2 |
Positive scale parameter |
Gamma |
Common positive shape parameter |
The admissible range of Alpha0 () is
X |
|
Y |
|
Sankaran PG, Nair NU (1993), A bivariate Pareto model and its applications to reliability, Naval Research Logistics, 40(7): 1013-1020.
Shih J-H, Lee W, Sun L-H, Emura T (2019), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, 48:1193-1220.
library(Bivariate.Pareto) SN.Pareto(5,2,1,1,1)library(Bivariate.Pareto) SN.Pareto(5,2,1,1,1)